@@ -15,9 +15,9 @@ from django.db import models
 from django.utils import timezone
 
 __all__ = (
-    'HerokuConnectFieldMixin', 'AnyType', 'ID', 'Checkbox', 'Currency',
-    'Date', 'DateTime', 'Email', 'EncryptedString', 'Number', 'Percent',
-    'Phone', 'Picklist', 'Text', 'TextArea', 'Time', 'URL', 'ExternalID',
+    'HerokuConnectFieldMixin', 'AnyType', 'ID', 'ExternalID', 'Checkbox', 'Number', 'Currency',
+    'Date', 'DateTime', 'Email', 'EncryptedString', 'Percent',
+    'Phone', 'Picklist', 'Text', 'TextArea', 'TextAreaLong', 'Time', 'URL',
 )
 
 
@@ -107,10 +107,12 @@ class ExternalID(HerokuConnectFieldMixin, models.UUIDField):
         return self.to_python(value)
 
 
-class Checkbox(HerokuConnectFieldMixin, models.NullBooleanField):
+class Checkbox(HerokuConnectFieldMixin, models.BooleanField):
     """Salesforce ``Checkbox`` field."""
 
-    pass
+    def __init__(self, *args, **kwargs):
+        kwargs['null'] = True
+        super().__init__(*args, **kwargs)
 
 
 class Number(HerokuConnectFieldMixin, models.DecimalField):
